@@ -23,6 +23,9 @@ class Act():
         self.uwsgi_linker()
         self.uwsgi_log = self.get_uwsgi_log()
 
+    def __unicode__(self):
+        return self.actname
+
     def get_settings(self):
         syspath = sys.path
         sys.path.insert(0,os.path.join(self.venue.VENUE_ROOT,'acts'))
