@@ -96,14 +96,16 @@ class Venue():
         self.acts = []
         acts_root = os.path.abspath(os.path.join(self.VENUE_ROOT,'acts'))
         acts_list = os.listdir(acts_root)
+        print 'ACTS_LIST:',acts_list
         for a in acts_list:
             try:
                 act=Act(self,a)
                 self.acts.append(act)
-            except:
+            except ImportError:
                 pass
 
 
+
     def __unicode__(self):
         s = 'Backstage Venue instance %s at %s' % (self.VENUE_NAME, self.VENUE_ROOT)
         return s
